/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global console, define, window */

/**
 * App module
 *
 * @module app
 * @requires {@link core/application}
 * @requires {@link views/main}
 * @namespace app
 */

define(
    'app',
    [
        'core/application',
        'views/main'
    ],
    function appInit(req) {
        'use strict';

        /**
         * Core application module object.
         *
         * @memberof app
         * @private
         * @type {Module}
         */
        var app = req('core/application');

        /**
         * Exits application.
         *
         * @memberof app
         * @private
         */
        function exit() {
            try {
                app.exit();
            } catch (err) {
                console.error('Error: ', err);
            }
        }

        /**
         * Handles hardware key tap event.
         *
         * @memberof app
         * @private
         * @param {Event} event
         */
        function onHardwareKeysTap(event) {
            if (event.keyName === 'back') {
                exit();
            }
        }

        /**
         * Initialize App module.
         *
         * @memberof app
         * @public
         */
        function init() {
            window.addEventListener('tizenhwkey', onHardwareKeysTap);
        }

        return {
            init: init
        };
    }
);
